@@ -8,7 +8,7 @@ use Carp;
 
 use subs qw();
 
-our $VERSION = '1.015';
+our $VERSION = '1.016';
 
 =encoding utf8
 
@@ -157,6 +157,7 @@ With major versions after 10, all point releases have the same identifier:
 	12 Monterey
 	13 Ventura
 	14 Sonoma
+	15 Sequoia
 
 =item minor_version_numbers( [ MAJOR ] )
 
@@ -181,6 +182,7 @@ my %names = (
 	'12' => [ 'Monterey' ],
 	'13' => [ 'Ventura' ],
 	'14' => [ 'Sonoma' ],
+	'15' => [ 'Sequoia' ],
 	 );
 
 my %release_dates = (
@@ -189,6 +191,7 @@ my %release_dates = (
 	12 => [ ],
 	13 => [ ],
 	14 => [ ],
+	15 => [ ],
 	);
 
 sub default_major_version { '10' }
@@ -507,7 +510,7 @@ brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2024, brian d foy <briandfoy@pobox.com>. All rights reserved.
+Copyright © 2007-2025, brian d foy <briandfoy@pobox.com>. All rights reserved.
 
 You may redistribute this under the terms of the Artistic License 2.0.
 
